| What's Cooking
Description: We help you get dinner on the table quickly, confidently, and inexpensively. Learn how to plan ahead, shop smart, save time, save money, master new skills, whip up new recipes, and prepare for holidays and parties — we're here whenever you need inspiration or advice in the kitchen. We'll also keep you up to date on food news and trends that affect how you shop. So come find out What's Cooking at Recipe.com every day!

# Make-Ahead Side: Sweet Potato, Parsnip, and Celery Root Mash

Diana Yen | December 22, 2014

With winter cooking in full swing, I’ve been making heartier meat dishes such as braises, stews, and roasts. One my favorite side dishes to accompany them is sweet potato mash. They’re less starchy than white ones and higher in nutrition, packed with loads of vitamin A. I liked the addition of parsnips in this recipe and added a bulb of celery root as well to give the dish another layer of earthy flavor.

### Get the recipe for sweet potato and parsnip mash here.

I began by scrubbing and peeling all of my root vegetables. Celery root can be a little tricky to work with since the skin is thick and bumpy, so I use the peeler first to remove as much of the exterior as possible. Then I trim off any missed spots with my knife. By cutting them all into 1-inch cubes, they’ll cook more evenly together in the pot.

I transferred the vegetables to a large stock pot and covered them in water with a large pinch of salt. After about 15 minutes of cooking, they were fork-tender. I drained and transferred everything to a large bowl.

Because I like mine with a little chunkier texture, I used my hand masher to mix them together. The butter and milk help to smooth out the mash, while the brown sugar and allspice round out the flavors.

This dish can be made the day ahead and reheated right before serving. Be sure to add an extra pat of butter on top to finish. Try this root vegetable mash as a sweet, earthy alternative to classic mashed potatoes at your next meal.

### Sweet Potato, Parsnip, and Celery Root Mash

Serves: 8
Prep Time: 15 minutes

1/4 pound celery root, peeled and cut into 1-inch pieces
1 pound parsnips, peeled and cut into 1-inch pieces
2 pounds sweet potatoes, peeled and cut into 1-inch pieces
1/2 cup 2% milk
1/4 cup packed brown sugar
2 tablespoons unsalted butter
3/4 teaspoon salt
1/4 teaspoon ground allspice

1. Combine parsnips and sweet potatoes in a medium pot; cover with 1 inch of cold water. Bring to a boil, then reduce heat to medium and simmer for 10 to 15 minutes, or until vegetables are tender and parsnips have lost their bitterness.
2. Drain cooked vegetables and immediately return to pot over low heat. Mash with milk, brown sugar, butter, salt, and allspice.

### Get the original recipe here.

Categories: Other Holidays & Parties | Tags: Christmas Side Dishes, Mashed Potatoes, Sweet Potatoes, Thanksgiving Side Dishes
No Comments | Post Your Comment

### Leave a Reply Cancel reply

Your email address will not be published. Required fields are marked *

Name *
Email *
Website
Let us know what you have to say:

Back to Top